package at.kugel.plugin.dependency;

import org.eclipse.jface.viewers.ITableLabelProvider;
import org.eclipse.jface.viewers.LabelProvider;
import org.eclipse.swt.graphics.Image;
import org.eclipse.ui.ISharedImages;
import org.eclipse.ui.PlatformUI;
/**
 * The view uses a label provider to define how model objects should be presented in the
 * view. Depending on type we choose another label.
 * @author Kugel, <i>Theossos Comp Group</i>
 */
public final class ViewLabelProvider extends LabelProvider implements ITableLabelProvider
{
   private String currentName = "";

   void setCurrentName(String currentName)
   {
      this.currentName = currentName;
   }

   public String getColumnText(Object obj, int index)
   {
      return getText(obj);
   }

   public Image getColumnImage(Object obj, int index)
   {
      final String name = obj.toString();
      if (name.equals(currentName))
      {
         // same
         return getImage(ISharedImages.IMG_OBJ_FILE);
      }
      if (name.startsWith(currentName + '.'))
      {
         // inner class
         return getImage(ISharedImages.IMG_OBJ_ELEMENT);
      }
      if (getPackageOf(name).equals(getPackageOf(currentName)))
      {
         // same package
         return getImage(ISharedImages.IMG_DEF_VIEW);
      }
      // outside
      return getImage(ISharedImages.IMG_TOOL_FORWARD);
   }

   private String getPackageOf(String fullClassName)
   {
      final int i = fullClassName.lastIndexOf('.');
      return i != -1 ? fullClassName.substring(0, i + 1) : "";
   }

   @Override
   public Image getImage(Object obj)
   {
      return PlatformUI.getWorkbench().getSharedImages().getImage(obj.toString());
   }

}